Module state

Module state 

Defines State, the core object which is acted upon during integration.

Structs

ConstantStateFnMut
Constant function of the state
DDEMutStateFnMut
Mutable time-, mutable position-, and past state-dependent function of the state
DDEStateFnMut
Time-, position-, and past state-dependent function of the state
ODE2MutStateFnMut
Time- and position-mutating function of the state
ODE2StateFnMut
Time- and position-depending function of the state
ODEMutStateFnMut
Position-mutating function of the state
ODEStateFnMut
Position-dependent function of the state
RKState
State is an object that represents the state of the equation during solving.
StateCoordFn
Struct that holds a reference to the state, and the coordinate index.
StateFnMutComposition
Composition of a regular function and a state function
TimeMutStateFnMut
Time-mutating function of the state
TimeStateFnMut
Time-dependent function of the state

Traits

MutStateFnMut
Trait, that defines how a function is evaluated at the state, which can also mutate the state.
State
Trait that abstracts state of the equation over used numerical method.
StateCoordFnTrait
Trait to erase generic parameter S from StateCoordFn
StateFnMut
Trait, that defines how a function is evaluated at the state.